@@ -31,9 +31,12 @@ $CFG->dbname = "pgmarket";
 $CFG->dbuser = "postgres";
 $CFG->dbpass = "postgres";
 
-$CFG->myname = "PgMarket 1.2.x";
+$CFG->myname = "PgMarket 1.3.x";
+
+$frames=1;
 
 $CFG->wwwroot     = "/~pratesi/pgmarket";	// without an ending "/"
+$CFG->firstpage   = "$CFG->wwwroot/firstpage.php";
 $CFG->dirroot     = "/home/pratesi/public_html/pgmarket";	// without an ending "/"
 $CFG->templatedir = "$CFG->dirroot/templates/";	// with an ending "/"
 $CFG->libdir      = "$CFG->dirroot/lib";	// without an ending "/"
@@ -78,9 +81,8 @@ if (! isset($SESSION)) {
 
 // Loaded modules
 $SESSION["brand_used"] = 1;
-$SESSION["iva_used"] = 1;
-//$SESSION["iva_value"] = 0;	// not significant if IVA is used
-$IVA = "VAT";
+$SESSION["iva_used"] = 0;
+$SESSION["iva_value"] = 0;	// not significant if IVA is not used
 
 $SESSION["price_must_be_integer"] = 0;
 	// 1 --> the price must be integer (Italian Lit, for example)
