@@ -54,7 +54,7 @@ function pvwbr(&$var) {
 	$appoggio = isset($var) ? htmlSpecialChars(stripslashes($var)) : "";
 	$appoggio = ereg_replace ("\n", "<br>", $appoggio);
 */
-	$appoggio = nl2br(stripslashes($var));
+	$appoggio = nl2br($var);
 	echo $appoggio == "" ? "&nbsp;" : $appoggio;
 }
 
@@ -245,4 +245,39 @@ function string_cleanup ($string) {
 
 }
 
+function string_cleanup_js ($string) {
+// "cleans up" a string containing "strange" characters
+
+	$string = str_replace(" ", "space", $string);
+	$string = str_replace("-", "minus", $string);
+	$string = str_replace("!", "exclam", $string);
+	$string = str_replace("", "sterling", $string);
+	$string = str_replace("$", "dollar", $string);
+	$string = str_replace("%", "percent", $string);
+	$string = str_replace("&", "ampersand", $string);
+	$string = str_replace("/", "slash", $string);
+	$string = str_replace("\\", "backslash", $string);
+	$string = str_replace("(", "parenleft", $string);
+	$string = str_replace(")", "parenright", $string);
+	$string = str_replace("[", "bracketleft", $string);
+	$string = str_replace("]", "bracketright", $string);
+	$string = str_replace("{", "braceleft", $string);
+	$string = str_replace("}", "braceright", $string);
+	$string = str_replace("?", "question", $string);
+	$string = str_replace("*", "asterisk", $string);
+	$string = str_replace("@", "at", $string);
+	$string = str_replace("", "paragraph", $string);
+	$string = str_replace(">", "greater", $string);
+	$string = str_replace("<", "lower", $string);
+	$string = str_replace("", "degree", $string);
+	$string = str_replace("#", "numbersign", $string);
+	$string = str_replace("~", "tilde", $string);
+	$string = str_replace("`", "grave", $string);
+	$string = str_replace("'", "apostrophe", $string);
+	$string = str_replace("", "cedilla", $string);
+
+	return $string;
+
+}
+
 ?>
