@@ -6,12 +6,14 @@ include("../application.inc.php");
 
 <html>
 <head>
-<LINK REL=StyleSheet HREF="<?=$CFG->wwwroot?>/styles/pgmarket.css" TYPE="text/css">
+<link rel=StyleSheet href="<?=$CFG->wwwroot?>/styles/pgmarket.css" type="text/css">
 </head>
 <body class=nav topmargin="0" leftmargin="0" marginwidth="5" marginheight="10">
 
 <h1><?=$Categories_Browsing?></h1>
 
+<h2><? print_category_tree($id) ?></h2>
+
 <table>
 <tr>
 <td class=label><?=$Categories?>:</td>
@@ -20,12 +22,7 @@ include("../application.inc.php");
 <td class=normal>
 <?
 build_category_navigator($categories);
-$categories = ".<div class=normal>Top</div>^" . $CFG->wwwroot . "/shopping/^main\n" . $categories;
-/*
-echo "<pre>";
-echo $categories;
-echo "</pre>";
-*/
+$categories = ".Top^" . $CFG->wwwroot . "/shopping/^main\n" . $categories;
 require("$CFG->libdir/treemenu.inc.php");
 ?>
 </td>
