@@ -23,7 +23,7 @@ include("../application.inc.php");
 /* if no product id is specified, go back to the main page */
 /*
 if (empty($id)) {
-	header("Location: $CFG->wwwroot");
+	header("Location: $CFG->firstpage");
 	die;
 }
 */
@@ -34,11 +34,11 @@ if (empty($id)) {
 		if (db_num_rows($qid)) {
 			list($id) = db_fetch_row($qid, 0);
 		} else {
-			header("Location: $CFG->wwwroot");
+			header("Location: $CFG->firstpage");
 			die;
 		}
 	} else {
-		header("Location: $CFG->wwwroot");
+		header("Location: $CFG->firstpage");
 		die;
 	}
 }
