@@ -17,7 +17,7 @@ if (!strpos($REFERER_AND_QUERY, "from_menu=yes")) {
 if ($frames) { ?>
 <script language="JavaScript">
 <!--
-parent.categories.location.reload('<?=$CFG->wwwroot?>/shopping/navigation.php?p=0');
+parent.categories.location.reload();
 parent.main.location.href="<?=$REFERER_AND_QUERY?>";
 // -->
 </script>
